build-qemu-robot-docker: upgrade to focal
The 'pip' version that comes with bionic is no longer able to
install some of the python modules we need. Specificially, we
end up with a failure as:
Traceback (most recent call last):
File "<string>", line 1, in <module>
File "/tmp/pip-build-lz9dedw0/cryptography/setup.py", line 14, in <module>
from setuptools_rust import RustExtension
ModuleNotFoundError: No module named 'setuptools_rust'
Rather than pin the cryptography module, which is actually a
dependency from a few levels down, upgrade the distro to focal to
pick up a new version of pip.
Signed-off-by: Patrick Williams <patrick@stwcx.xyz>
Change-Id: Ief9aaccbe14b835a2dcae5c7d53cc5969f044cf3
diff --git a/scripts/build-qemu-robot-docker.sh b/scripts/build-qemu-robot-docker.sh
index 9f5ce96..0ff95e9 100755
--- a/scripts/build-qemu-robot-docker.sh
+++ b/scripts/build-qemu-robot-docker.sh
@@ -13,14 +13,14 @@
# parm1: <optional, the name of the docker image to generate>
# default is openbmc/ubuntu-robot-qemu
# param2: <optional, the distro to build a docker image against>
# default is ubuntu:bionic
set -uo pipefail
http_proxy=${http_proxy:-}
DOCKER_IMG_NAME=${1:-"openbmc/ubuntu-robot-qemu"}
-DISTRO=${2:-"ubuntu:bionic"}
+DISTRO=${2:-"ubuntu:focal"}
UBUNTU_MIRROR=${UBUNTU_MIRROR:-""}
PIP_MIRROR=${PIP_MIRROR:-""}
@@ -13,14 +13,14 @@
# default is openbmc/ubuntu-robot-qemu
# param2: <optional, the distro to build a docker image against>
-# default is ubuntu:bionic
+# default is ubuntu:focal
set -uo pipefail
http_proxy=${http_proxy:-}